<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://www.phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/admin_log.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Gbook;

class GbookLog extends GbookServer {
    private static $instance = NULL;
    private $allowed_pages = ["delete", "activate", "hide", "new_message", "edit"];
    public $action = '';

    public function __construct() {
        parent::__construct();
        self::CurrentSetup();
        $this->action = in_array(get('action'), $this->allowed_pages) ? get('action') : '';
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }

        return self::$instance;
    }

    public function displyLog() {
        switch ($this->action) {
            case "delete":
                if (checkgroup($this->gbookSettings['gs_moderated_access']) && get('del_id', FILTER_VALIDATE_INT)) {
                    self::deleteLog(get('del_id', FILTER_VALIDATE_INT));
                    addNotice('warning', self::$locale['GBOK_112']);
                }
                redirect(FUSION_SELF.fusion_get_aidlink().'&section=logs');
                break;
            case "activate":
                if (checkgroup($this->gbookSettings['gs_moderated_access']) && get('gl_id', FILTER_VALIDATE_INT)) {
                    self::logMod(get('gl_id', FILTER_VALIDATE_INT));
                    addNotice('success', self::$locale['GBOK_110']);
                }
                redirect(FUSION_SELF.fusion_get_aidlink().'&section=logs');
                break;
            default:
                self::logList();
                break;
        }

    }

    private function logList() {
        if (check_post('delete_messages')) {
            dbquery("TRUNCATE TABLE ".DB_GB_LOG);
            addNotice('success', self::$locale['GBOK_122']);
            redirect(FUSION_SELF.fusion_get_aidlink());
        }

    	$glog = self::GetGbookLog();
    	opentable(self::$locale['GBOK_101']);
        if (!empty($glog['maxrows'])) {
            openside('');
            fusion_confirm_exit();
            add_to_jquery("$('#delete_messages').bind('click', function() { return confirm('".self::$locale['GBOK_123']."'); });");
            echo form_button('delete_messages', self::$locale['GBOK_124'], self::$locale['GBOK_124'], ['class' => 'btn-danger', 'icon' => 'fa fa-trash-o']);
            closeside();

            if (!empty($glog['data'])) {
                echo "<div class='table-responsive'><table class='table table-hover table-striped'>";
                echo "<thead><tr>";
                echo "<th>".self::$locale['GBOK_115']."</th>";
                echo "<th>".self::$locale['GBOK_116']."</th>";
                echo "<th>".self::$locale['GBOK_117']."</th>";
                echo "<th>".self::$locale['GBOK_126']."</th>";
                echo "<th>".self::$locale['GBOK_118']."</th>";
                echo "<th>".self::$locale['GBOK_119']."</th>";
                echo "<th>".self::$locale['GBOK_120']."</th>";
                echo "<th></th>";
                echo "</tr></thead>";
                echo "<tbody>";
                foreach ($glog['data'] as $log_data) {
            	$web_log = '';
                if ($log_data['gl_url']) {
                	$wtitle = !empty($log_data['gb_webtitle']) ? $log_data['gl_urltitle'] : $log_data['gl_url'];
                    $link = !preg_match("@^http(s)?\:\/\/@i", $log_data['gl_url']) ? "http://".$log_data['gl_url'] : $log_data['gl_url'];
                    $web_log = "<a href='".$link."' title='".$wtitle."' target='_blank'>".$wtitle."</a>";
                }
                    echo "<tr>";
                    echo "<td class='text-left'>".parse_text($log_data['gl_message'], [
                        'parse_smileys'        => TRUE,
                        'parse_bbcode'         => TRUE,
                        'default_image_folder' => NULL,
                        'add_line_breaks'      => 'y'
                    ])."</td>";
                    echo "<td>".$log_data['gl_name']."</td>";
                    echo "<td>".showdate("longdate",$log_data['gl_datestamp'])."</td>";
                    echo "<td>".$log_data['gl_type']."</td>";
                    echo "<td>".$log_data['gl_ip']."</td>";
                    echo "<td>".$log_data['gl_email']."</td>";
                    echo "<td>".$web_log."</td>";
                    echo "<td><a href='".FUSION_SELF.fusion_get_aidlink()."&section=logs&action=activate&gl_id=".$log_data["gl_id"]."'><i class='fa fa-check fa-lg'></i></a>&nbsp;|&nbsp
                        <a href='".FUSION_SELF.fusion_get_aidlink()."&section=logs&action=delete&del_id=".$log_data['gl_id']."'><i class='fa fa-trash fa-lg'></i></a></td>";
                    echo "</tr>";
                }
                echo "</tbody></table></div>";
            }

            if (!empty($glog['pagenav'])) {
                echo "<div class='display-inline-block pull-right'>";
                echo $glog['pagenav'];
                echo "</div>";
            }
        } else {
            echo "<div class='text-center'>".self::$locale['GBOK_127']."</div>";
        }
        closetable();

    }

    private function logMod($id = NULL) {
        $result = dbquery("SELECT * FROM ".DB_GB_LOG." WHERE gl_id = :glid", [':glid' => (int)$id]);
        if (dbrows($result)) {
            $data = dbarray($result);
            $save = [
                'gb_id'        => '',
                'gb_name'      => $data['gl_name'],
                'gb_email'     => $data['gl_email'],
                'gb_weburl'    => $data['gl_url'],
                'gb_webtitle'  => $data['gl_urltitle'],
                'gb_message'   => $data['gl_message'],
                'gb_show'      => 1,
                'gb_datestamp' => $data['gl_datestamp'],
                'gb_ip'        => $data['gl_ip'],
            ];

            dbquery_insert(DB_GUESTBOOK, $save, 'save');
            self::deleteLog($id);
            addNotice('success', self::$locale['GBOK_110']);
            redirect(FUSION_SELF.fusion_get_aidlink());
        }
    }

    private function deleteLog($id = NULL) {
        dbquery("DELETE FROM ".DB_GB_LOG." WHERE gl_id = :glid", [':glid' => (int)$id]);
    }

}
