<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://www.phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/admin_publish.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Gbook;

class GbookPublis extends GbookServer {
    private static $instance = NULL;
    private $allowed_pages = ["delete", "activate", "unpublish", "new_message", "edit"];
    public $action = '';

    public function __construct() {
        parent::__construct();
        self::CurrentSetup();
        $this->action = in_array(get('action'), $this->allowed_pages) ? get('action') : '';

        $allowed_actions = array_flip($this->allowed_pages);
        $table_action = post('gbookaction');
        if (check_post('gbookaction') && isset($allowed_actions[$table_action])) {

            $input = (check_post('gb_id')) ? explode(",", sanitizer(['gb_id'], 0, 'gb_id')) : "";
            if (!empty($input)) {
                foreach ($input as $gb_id) {
                    // check input table
                    if (self::verifyGbook($gb_id) && fusion_safe()) {

                        switch ($table_action) {
                            case "activate":
                                self::GbookMod(1, (int)$gb_id);
                                addNotice('success', self::$locale['GBOK_110']);
                                break;
                            case "unpublish":
                                self::GbookMod(0, (int)$gb_id);
                                addNotice('warning', self::$locale['GBOK_111']);
                                break;
                            case "delete":
                                self::deleteGbook($gb_id);
                                addNotice('warning', self::$locale['GBOK_112']);
                                break;
                            default:
                                redirect(FUSION_REQUEST);
                        }
                    }
                }
                redirect(FUSION_REQUEST);
            }
            addNotice('warning', self::$locale['GBOK_113']);
            redirect(FUSION_REQUEST);
        }
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }

        return self::$instance;
    }

    public function display() {
        switch ($this->action) {
            case "new_message":
                self::gbookForm();
                break;
            case "edit":
                self::gbookForm(get('gb_id', FILTER_VALIDATE_INT));
                break;
            case "delete":
                if (checkgroup($this->gbookSettings['gs_moderated_access']) && get('del_id', FILTER_VALIDATE_INT)) {
                    self::deleteGbook(get('del_id', FILTER_VALIDATE_INT));
                    addNotice('warning', self::$locale['GBOK_112']);
                }
                redirect(FUSION_SELF.fusion_get_aidlink());
                break;
            case "activate":
                if (checkgroup($this->gbookSettings['gs_moderated_access']) && get('gb_id', FILTER_VALIDATE_INT)) {
                    self::GbookMod(1, get('gb_id', FILTER_VALIDATE_INT));
                    addNotice('success', self::$locale['GBOK_110']);
                }
                redirect(FUSION_SELF.fusion_get_aidlink());
                break;
            case "unpublish":
                if (checkgroup($this->gbookSettings['gs_moderated_access']) && get('gb_id', FILTER_VALIDATE_INT)) {
                    self::GbookMod(0, get('gb_id', FILTER_VALIDATE_INT));
                    addNotice('warning', self::$locale['GBOK_111']);
                }
                redirect(FUSION_SELF.fusion_get_aidlink());
                break;
            default:
                self::gbookList();
                break;
        }
    }

    private function gbookList() {

        opentable(self::$locale['GBOK_100']);
        $result= self::GetAdminGbook();

        echo "<div class='clearfix'>";
        echo "<div class='pull-right'>";
        echo "<a class='btn btn-sm btn-success' href='".FUSION_SELF.fusion_get_aidlink()."&section=publish&action=new_message'><i class='fa fa-plus m-r-10'></i>".self::$locale['GBOK_012']."</a>
            <button type='button' class='hidden-xs m-l-5 btn btn-sm btn-default' onclick=\"run_admin('activate', '#gbookaction', '#gbooktable');\">
            <i class='fa fa-check m-r-10'></i>".self::$locale['publish']."</button>
            <button type='button' class='hidden-xs m-l-5 btn btn-sm btn-default' onclick=\"run_admin('unpublish', '#gbookaction', '#gbooktable');\">
            <i class='fa fa-ban m-r-10'></i>".self::$locale['GBOK_114']."</button>
            <button type='button' class='hidden-xs m-l-5 btn btn-sm btn-danger' onclick=\"run_admin('delete', '#gbookaction', '#gbooktable');\">
            <i class='fa fa-trash-o m-r-10'></i>".self::$locale['delete']."</button></div></div>";

        if (dbrows($result['data'])) {
            echo openform('gbooktable', 'post', FUSION_REQUEST);
            echo form_hidden('gbookaction');
            echo "<div class='table-responsive'><table class='table table-hover table-striped'>";
            echo "<thead><tr>";
            echo "<th class='hidden-xs'></th>";
            echo "<th>".self::$locale['GBOK_115']."</th>";
            echo "<th>".self::$locale['GBOK_116']."</th>";
            echo "<th>".self::$locale['GBOK_117']."</th>";
            echo "<th>".self::$locale['GBOK_118']."</th>";
            echo "<th>".self::$locale['GBOK_119']."</th>";
            echo "<th>".self::$locale['GBOK_120']."</th>";
            echo "<th></th>";
            echo "</tr></thead>";
            echo "<tbody>";
            while($data = dbarray($result['data'])) {
            	$web = '';
                if ($data['gb_weburl']) {
                	$wtitle = !empty($data['gb_webtitle']) ? $data['gb_webtitle'] : $data['gb_weburl'];
                    $link = !preg_match("@^http(s)?\:\/\/@i", $data['gb_weburl']) ? "http://".$data['gb_weburl'] : $data['gb_weburl'];
                    $web = "<a href='".$link."' title='".$wtitle."' target='_blank'>".$wtitle."</a>";
                }
                $gtitle = !empty($data["gb_show"]) ? self::$locale['publish'] : self::$locale['GBOK_114'];
                $gclass = !empty($data["gb_show"]) ? "fa-check" : "fa-remove";
                $act = empty($data["gb_show"]) ? 'activate' : 'unpublish';
                echo "<tr>";
                echo "<td class='hidden-xs'>".form_checkbox('gb_id[]', '', '', ['input_id' => 'gbook'.$data['gb_id'], 'value' => $data['gb_id'], 'class' => 'm-0'])."</td>";
                echo "<td class='text-left'>".parse_textarea($data['gb_message'], TRUE, TRUE, FALSE, NULL, TRUE)."</td>";
                echo "<td>".$data["gb_name"]."</td>";
                echo "<td>".showdate("longdate", $data["gb_datestamp"])."</td>";
                echo "<td>".$data["gb_ip"]."</td>";
                echo "<td>".$data["gb_email"]."</td>";
                echo "<td>".$web."</td>";
                echo "<td><a href='".FUSION_SELF.fusion_get_aidlink()."&section=publish&action=".$act."&gb_id=".$data["gb_id"]."' title='".$gtitle."'><i class='fa $gclass fa-lg'></i></a>&nbsp;|&nbsp";
                echo "<a href='".FUSION_SELF.fusion_get_aidlink()."&section=publish&action=edit&gb_id=".$data["gb_id"]."' title='".self::$locale['edit']."'><i class='fa fa-pencil fa-lg'></i></a>&nbsp;|&nbsp";
                echo "<a href='".FUSION_SELF.fusion_get_aidlink()."&section=publish&action=delete&del_id=".$data["gb_id"]."' title=".self::$locale['delete']."><i class='fa fa-trash fa-lg'></i></a></td>";
                echo "</tr>";

            }
            echo "</tbody></table></div>";
            echo closeform();
        } else {
        	echo "<div class='text-center'>".self::$locale['GBOK_121']."</div>";
        }

        if (!empty($result['pagenav'])) {
            echo "<div class='display-inline-block pull-right'>";
            echo $result['pagenav'];
            echo "</div>";
        }
        closetable();
    }

    public function gbookForm($id = NULL) {
        if(!empty($id)) {
            $result = dbquery("SELECT * FROM ".DB_GUESTBOOK." WHERE gb_id = :gbid ORDER BY gb_datestamp DESC LIMIT 0,1", [':gbid' => (int)$id]);
            if (dbrows($result)) {
                $gbook = dbarray($result);
            }
        } else {
            $gbook = $this->def_gbook;
        }

        if (!fusion_get_settings('tinymce_enabled')) {
            $gbookSettings = [
                'required'    => TRUE,
                'preview'     => TRUE,
                'html'        => TRUE,
                'placeholder' => self::$locale['GBOK_027'],
                'form_name'   => 'gbookform',
                'wordcount'   => TRUE,
                'autosize'    => TRUE
            ];
        } else {
            $gbookSettings = [
                'required'   => TRUE,
                'type'       => 'tinymce',
                'tinymce'    => 'advanced',
                'form_name'  => 'gbookform'
            ];
        }
        $userdata = fusion_get_userdata();
        $gbook['gb_name'] = empty($gbook['gb_name']) ? $userdata['user_name'] : $gbook['gb_name'];
        $gbook['gb_email'] = empty($gbook['gb_email']) ? (iMEMBER ? $userdata['user_email'] : $gbook['gb_email']) : $gbook['gb_email'];
        $gbook['gb_weburl'] = empty($gbook['gb_weburl']) ? (column_exists('users', 'user_web') ? (iMEMBER ? $userdata['user_web'] : $gbook['gb_weburl']) : $gbook['gb_weburl']) : $gbook['gb_weburl'];

        opentable(self::$locale['GBOK_100']);
        echo openform('gbookform', 'post', FUSION_REQUEST);
        echo form_text('gb_name', self::$locale['GBOK_029'], $gbook['gb_name'], [
            'required'    => TRUE,
            'placeholder' => self::$locale['GBOK_030']
        ]).
        form_text('gb_email', self::$locale['GBOK_031'], $gbook['gb_email'], [
            'required'    => $this->gbookSettings['gs_email_required'] ? TRUE : FALSE,
            'placeholder' => self::$locale['GBOK_032']
        ]).
        form_text('gb_weburl', self::$locale['GBOK_033'], $gbook['gb_weburl'], [
            'type'        => 'url',
            'regex'       => 'http(s)?\:\/\/(.*?)',
            'placeholder' => self::$locale['GBOK_034']
        ]).
        form_text('gb_webtitle', self::$locale['GBOK_035'], $gbook['gb_webtitle'], [
            'placeholder' => self::$locale['GBOK_036']
        ]).
        form_textarea('gb_message', self::$locale['GBOK_037'], $gbook['gb_message'], $gbookSettings).
        form_button('gbsubmit', self::$locale['publish'], self::$locale['publish'], ['class' => 'btn-sm btn-success']);
        closeform();
        closetable();
    }

    private function GbookMod($mod = NULL, $id = NULL) {
        dbquery("UPDATE ".DB_GUESTBOOK." SET gb_show = :gbshow WHERE gb_id = :gbid", [':gbshow' => $mod, ':gbid' => (int)$id]);
    }

    private function deleteGbook($id) {
        if (!empty($id)) {
            $i = 0;
            if (is_array($id)) {
                foreach ($id as $key => $right) {
                    if (self::verifyGbook($key)) {
                        dbquery("DELETE FROM ".DB_GUESTBOOK." WHERE gb_id = :gbid", [':gbid' => (int)$key]);
                        $i++;
                    }
                }
            } else {
                if (self::verifyGbook($id)) {
                    dbquery("DELETE FROM ".DB_GUESTBOOK." WHERE gb_id = :gbid", [':gbid' => (int)$id]);
                }
            }
        }
    }
}
