<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://www.phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/admin_settings.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Gbook;

class GbookSettings extends GbookServer {
    private static $instance = NULL;

    public function __construct() {
        parent::__construct();
        self::CurrentSetup();
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }

        return self::$instance;
    }

    public function settingsForm() {
        if (check_post('savesettings')) {
            $savesettings = [
                'gs_id'               => $this->gbookSettings['gs_id'],
                'gs_moderated'        => check_post('gs_moderated') ? 1 : 0,
                'gs_notify_kind'      => sanitizer('gs_notify_kind', '0', 'gs_notify_kind'),
                'gs_num'              => sanitizer('gs_num', 0, 'gs_num'),
                'gs_email_required'   => check_post('gs_email_required') ? 1 : 0,
                'gs_email_hidden'     => check_post('gs_email_hidden') ? 1 : 0,
                'gs_flood_time'       => sanitizer('gs_flood_time', 3600, 'gs_flood_time'),
                'gs_spam_words'       => sanitizer('gs_spam_words', '', 'gs_spam_words'),
                'gs_moderated_access' => sanitizer(['gs_moderated_access'], 0, 'gs_moderated_access')
            ];
            if (fusion_safe()) {
            	dbquery_insert(DB_GB_SETTINGS, $savesettings, 'update');
            	addNotice('success', self::$locale['GBOK_220']);
            }
            redirect(FUSION_REQUEST);
        }
        opentable(self::$locale['GBOK_102']);
        echo openform('settingsform', 'post', FUSION_REQUEST);
        echo form_checkbox('gs_moderated', self::$locale['GBOK_206'], $this->gbookSettings['gs_moderated'], [
            'inline' => TRUE,
            'toggle' => TRUE
        ]);
        echo form_select('gs_notify_kind', self::$locale['GBOK_209'], $this->gbookSettings['gs_notify_kind'], [
            'options'    => [0 => self::$locale['GBOK_210'], 'pm' => self::$locale['GBOK_211'], 'mail' => self::$locale['GBOK_212']],
            'inline'     => TRUE
        ]);
        echo form_text('gs_num', self::$locale['GBOK_203'], $this->gbookSettings['gs_num'], [
            'inline'      => TRUE,
            'max_length'  => 4,
            'inner_width' => '250px',
            'width'       => '150px',
            'type'        => 'number'
        ]);
        echo form_checkbox('gs_email_required', self::$locale['GBOK_204'], $this->gbookSettings['gs_email_required'], [
            'inline' => TRUE,
            'toggle' => TRUE
        ]);
        echo form_checkbox('gs_email_hidden', self::$locale['GBOK_205'], $this->gbookSettings['gs_email_hidden'], [
            'inline' => TRUE,
            'toggle' => TRUE
        ]);
        echo form_text('gs_flood_time', self::$locale['GBOK_219'], $this->gbookSettings['gs_flood_time'], [
            'inline'      => TRUE,
            'max_length'  => 5,
            'inner_width' => '250px',
            'width'       => '150px',
            'ext_tip'     => self::$locale['GBOK_221'],
            'type'        => 'number'
        ]);
        echo form_textarea('gs_spam_words', self::$locale['GBOK_216'], $this->gbookSettings['gs_spam_words'], [
            'ext_tip'  => self::$locale['GBOK_217'],
            'inline'   => TRUE
        ]);
        echo form_select('gs_moderated_access[]', self::$locale['GBOK_208'], $this->gbookSettings['gs_moderated_access'], [
            'multiple'   => TRUE,
            'width'      => '100%',
            'options'    => ['-101' => self::$locale['user1'], '-102' => self::$locale['user2'], '-103' => self::$locale['user3']],
            'max_select' => 1,
            'inline'     => TRUE
        ]);
        echo form_button('savesettings', self::$locale['save'], self::$locale['save'], ['class' => 'btn-primary']);
        echo closeform();
        closetable();
    }
}
