<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://www.phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/guestbook.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Gbook;

class GbookLib extends GbookServer {
    private static $instance = NULL;
    private $gBook = [];

    public function __construct() {
        parent::__construct();
        add_to_title(self::$locale['GBOK_010']);
        self::CurrentSetup();
        self::defineGbookMods($this->gbookSettings['gs_moderated_access']);
        $this->action = check_get('action') && (get('action') == 'new_message') ? get('action') : '';
    }

    public static function getInstance() {
        if (self::$instance === NULL) {
            self::$instance = new static();
        }
       return self::$instance;
    }

    public function Display() {
    	if (check_post('gbsubmit')) {
    	    if (iGUEST) {
    	        $_CAPTCHA_IS_VALID = FALSE;
    	        include INCLUDES."captchas/".fusion_get_settings('captcha')."/captcha_check.php";
    	        if (!$_CAPTCHA_IS_VALID) {
    	            fusion_stop();
    	            addNotice('warning', self::$locale['GBOK_020']);
    	            redirect(FUSION_REQUEST);
    	        }
    	    }

    		$save = [
    		    'gb_id'           => '',
    		    'gb_name'         => sanitizer('gb_name', '', 'gb_name'),
    		    'gb_email'        => sanitizer('gb_email', '', 'gb_email'),
    		    'gb_weburl'       => sanitizer('gb_weburl', '', 'gb_weburl'),
    		    'gb_webtitle'     => sanitizer('gb_webtitle', '', 'gb_webtitle'),
    		    'gb_message'      => sanitizer('gb_message', '', 'gb_message'),
    		    'gb_show'         => gMOD,
    		    'gb_datestamp'    => time(),
    		    'gb_ip'           => USER_IP,
    		    'gb_language'     => LANGUAGE
    		];

            if (fusion_safe()) {
                if (self::GbookFloodControl(USER_IP)) {
                    self::GbookLoged("flood", $save['gb_name'], $save['gb_email'], $save['gb_weburl'], $save['gb_message'], $save['gb_webtitle']);
                    addNotice("danger", (sprintf(self::$locale['GBOK_021'], ($this->gbookSettings['gs_flood_time']))));
                    redirect(GBOOK_PATH.'guestbook.php');
                }

                $spamcheck = $save['gb_name'].$save['gb_weburl'].$save['gb_webtitle'].$save['gb_message'];
                if (self::GbookSpamControl($spamcheck)) {
                    self::GbookLoged("spam", $save['gb_name'], $save['gb_email'], $save['gb_weburl'], $save['gb_message'], $save['gb_webtitle']);
                    addNotice("warning", self::$locale['GBOK_022']);
                    redirect(GBOOK_PATH.'guestbook.php');
                }

                dbquery_insert(DB_GUESTBOOK, $save, 'save');

                if(!empty($this->gbookSettings['gs_moderated'])) {
                    $result = self::GbookNotify($this->gbookSettings['gs_moderated_access']);
                    if($this->gbookSettings['gs_notify_kind'] == "pm") {
                        $text =  sprintf(self::$locale['GBOK_023'], $save['gb_name']).":\n\n[quote]".$save['gb_message']."[/quote]\n\n".self::$locale['GBOK_024'];
                        $pm_from_id = iMEMBER ? fusion_get_userdata('user_id') : "1";
                        while ($data = dbarray($result)) {
                            dbquery("INSERT INTO ".DB_MESSAGES." (message_to, message_from, message_user, message_subject, message_message, message_smileys, message_read, message_datestamp, message_folder) VALUES ('".$data['user_id']."', '".$pm_from_id."', '".$data['user_id']."', '".self::$locale['GBOK_025']."', '".$text."', 'n', '0', '".time()."', '0')");
                        }

                    } else if ($this->gbookSettings['gs_notify_kind'] == "mail") {
                        require_once INCLUDES."sendmail_include.php";
                        $text =  sprintf(self::$locale['GBOK_023'], $save['gb_name']).":\n\n".$save['gb_message']."\n\n".self::$locale['GBOK_024'];
                        while ($data = dbarray($result)) {
                            sendemail($data['user_name'], $data['user_email'], $settings['siteusername'], $settings['siteemail'], $settings['sitename']." - ".self::$locale['GBOK_025'], $text);
                        }
                    }
                }
                addNotice("success", self::$locale['GBOK_026']);
                redirect(GBOOK_PATH.'guestbook.php');
            }
    	}

        switch ($this->action) {
            case "new_message":
                $info = $this->gbookForm();
                displayGbookForm($info);
                break;
            default:
                $info = self::GetCurrentGbook();
                displayGbook($info);
        }
    }


    private function gbookForm() {
        if (!fusion_get_settings('tinymce_enabled')) {
            $gbookSettings = [
                'required'    => TRUE,
                'preview'     => TRUE,
                'html'        => TRUE,
                'placeholder' => self::$locale['GBOK_027'],
                'form_name'   => 'gbookform',
                'wordcount'   => TRUE,
                'autosize'    => TRUE
            ];
        } else {
            $gbookSettings = [
                'required'   => TRUE,
                'type'       => 'tinymce',
                'tinymce'    => 'advanced',
                'form_name'  => 'gbookform'
            ];
        }
        $userdata = fusion_get_userdata();
        $this->def_gbook['gb_name'] = empty($this->def_gbook['gb_name']) ? $userdata['user_name'] : $this->def_gbook['gb_name'];
        $this->def_gbook['gb_email'] = empty($this->def_gbook['gb_email']) ? (iMEMBER ? $userdata['user_email'] : $this->def_gbook['gb_email']) : $this->def_gbook['gb_email'];
        $this->def_gbook['gb_weburl'] = empty($this->def_gbook['gb_weburl']) ? (column_exists('users', 'user_web') ? (iMEMBER ? $userdata['user_web'] : $this->def_gbook['gb_weburl']) : $this->def_gbook['gb_weburl']) : $this->def_gbook['gb_weburl'];
        $inf['captcha_code'] = '';
        if (iGUEST) {
            include INCLUDES.'captchas/'.fusion_get_settings('captcha').'/captcha_display.php';
            $captcha_settings = [
                'captcha_id' => 'captcha_contact',
                'input_id'   => 'captcha_code_contact',
                'image_id'   => 'captcha_image_contact'
            ];
            $inf['captcha'] = display_captcha($captcha_settings);
            if (!isset($_CAPTCHA_HIDE_INPUT) || (!$_CAPTCHA_HIDE_INPUT)) {
                $inf['captcha_code'] = form_text('captcha_code', self::$locale['GBOK_028'], '', [
                    'required'         => TRUE,
                    'autocomplete_off' => TRUE,
                    'input_id'         => 'captcha_code_gbook'
                ]);
            }
        }

        $info = [
            'gbname'     => form_text('gb_name', self::$locale['GBOK_029'], $this->def_gbook['gb_name'], [
                'required'    => TRUE,
                'placeholder' => self::$locale['GBOK_030']
            ]),
            'gbemail'    => form_text('gb_email', self::$locale['GBOK_031'], $this->def_gbook['gb_email'], [
                'required'    => $this->gbookSettings['gs_email_required'] ? TRUE : FALSE,
                'placeholder' => self::$locale['GBOK_032']
            ]),
            'gbweburl'   => form_text('gb_weburl', self::$locale['GBOK_033'], $this->def_gbook['gb_weburl'], [
                'type'        => 'url',
                'regex'       => 'http(s)?\:\/\/(.*?)',
                'placeholder' => self::$locale['GBOK_034']
            ]),
            'gbwebtitle' => form_text('gb_webtitle', self::$locale['GBOK_035'], $this->def_gbook['gb_webtitle'], [
                'placeholder' => self::$locale['GBOK_036']
            ]),
            'gbmessage'  => form_textarea('gb_message', self::$locale['GBOK_037'], $this->def_gbook['gb_message'], $gbookSettings),
            'gbsubmit'   => form_button('gbsubmit', self::$locale['submit'], self::$locale['submit'], ['class' => 'btn-sm btn-success'])
        ] +$inf;
        return $info;
    }
}