<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://www.phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/server.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Gbook;

abstract class GbookServer {
    protected static $locale = [];
    public $sqlGbook = NULL;
    public $gbookSettings = [];
    public $def_gbook = [
        'gb_id'           => '',
        'gb_name'         => '',
        'gb_email'        => '',
        'gb_weburl'       => '',
        'gb_webtitle'     => '',
        'gb_message'      => '',
        'gb_show'         => 0,
        'gb_datestamp'    => 0,
        'gb_ip'           => '0.0.0.0'
    ];

    public function __construct() {
        self::$locale = fusion_get_locale("", GBOOK_LOCALE);
    	require_once GBOOK_PATH."templates/guestbook.tpl.php";
        $this->sqlGbook = new GbookSql();
    }

	public function CurrentSetup() {
        $this->gbookSettings = dbarray(dbquery($this->sqlGbook->getConfQuery()));
	}

	public function GetCurrentGbook() {

        $limit = $this->gbookSettings['gs_num']; //20;
        $max_rows = dbcount("(gb_id)", DB_GUESTBOOK, (multilang_table("GBOK") ? in_group('gb_language', LANGUAGE).(iADMIN ? '' : " AND ") : '').(iADMIN ? '' : "gb_show='1'"));
        $rowstart = get_rowstart("rowstart", $max_rows);

        $result = dbquery($this->sqlGbook->getGbookQuery(['condition' => (multilang_table("GBOK") ? in_group('gb_language', LANGUAGE).(iADMIN ? '' : " AND ") : '').(iADMIN ? '' : "gb_show='1'"), 'order' => 'gb_datestamp DESC', 'limit' => "$rowstart, $limit"]));

        $gbook =[];
        if (dbrows($result)) {
            while ($data = dbarray($result)) {
                $gbook[] = $data;
            }
        }
        $info = [
            'limit'    => $limit,
            'maxrows'  => $max_rows,
            'rowstart' => $rowstart,
            'pagenav'  => makepagenav($rowstart, $limit, $max_rows, 3, INFUSIONS."fh_guest_book/guestbook.php?"),
            'email'    => $this->gbookSettings['gs_email_hidden'],
            'data'     => $gbook,
            'flood'    => self::GbookFloodControl(USER_IP)
        ];

        return $info;
	}

	public function GetAdminGbook() {

        $limit = $this->gbookSettings['gs_num']; //20;
        $max_rows = dbcount("(gb_id)", DB_GUESTBOOK, "");
        $rowstart = get_rowstart("rowstart", $max_rows);

        $result = dbquery($this->sqlGbook->getGbookQuery(['order' => 'gb_datestamp DESC', 'limit' => "$rowstart, $limit"]));

        $info = [
            'pagenav'  => makepagenav($rowstart, $limit, $max_rows, 3, FUSION_SELF.fusion_get_aidlink()."&"),
            'data'     => $result
        ];

        return $info;
	}

    public function GetGbookLog() {
        $limit = $this->gbookSettings['gs_num']; //20;
        $max_rows = dbcount("(gl_id)", DB_GB_LOG, '');
        $rowstart = get_rowstart("rowstart", $max_rows);

        $result = dbquery($this->sqlGbook->getLogQuery(['order' => 'gl_datestamp DESC', 'limit' => "$rowstart, $limit"]));
        $glog =[];
        if (dbrows($result)) {
            while ($data = dbarray($result)) {
                $glog[] = $data;
            }
        }
        $info = [
            'limit'    => $limit,
            'maxrows'  => $max_rows,
            'rowstart' => $rowstart,
            'pagenav'  => makepagenav($rowstart, $limit, $max_rows, 3, FUSION_SELF.fusion_get_aidlink().'&'),
            'data'     => $glog
        ];

        return $info;
    }

    public function GbookFloodControl($ip) {
        $flood = time() - ($this->gbookSettings['gs_flood_time']*60);
        $result = dbquery("SELECT gb_id FROM ".DB_GUESTBOOK." WHERE gb_ip = :gbip AND gb_datestamp >= :datestamp".(multilang_table("GBOK") ? " AND ".in_group('gb_language', LANGUAGE) : ''), [':gbip' => $ip, ':datestamp' => $flood]);
        if(dbrows($result)) {
            if (dbcount("(gl_id)", DB_GB_LOG, "gl_ip = :glip && gl_type = :gltype", [':glip' => USER_IP, ':gltype' => 'flood']) > 4) {
                if (!iMEMBER) {
                    dbquery("INSERT INTO ".DB_BLACKLIST." (blacklist_ip, blacklist_ip_type, blacklist_reason) VALUES ('".USER_IP."', '".USER_IP_TYPE."', 'flood')");
                }
            }
            return TRUE;
        }
        return FALSE;
    }

    public function GbookLoged($type, $name, $email, $url, $msg, $title) {
        $savelog = [
            'gl_id'        => '',
            'gl_type'      => $type,
            'gl_userid'    => iMEMBER ? fusion_get_userdata('user_id') : '',
            'gl_ip'        => USER_IP,
            'gl_name'      => $name,
            'gl_email'     => $email,
            'gl_url'       => $url,
            'gl_message'   => $msg,
            'gl_urltitle'  => $title,
            'gl_datestamp' => time()
        ];
        dbquery_insert(DB_GB_LOG, $savelog, 'save');
    }

    public function GbookSpamControl($text) {
        if (!empty($this->gbookSettings['gs_spam_words'])) {
            $word_list = explode("\r\n", $this->gbookSettings['gs_spam_words']);
            for ($i=0; $i < count($word_list); $i++) {
                if ($word_list[$i] != "") {
                    if (preg_match("/".$word_list[$i]."/si", $text)) {
                        return TRUE;
                    }
                }
            }
        }
        return FALSE;
    }

    public function defineGbookMods($moderated = NULL) {
        $gbmod = FALSE;
        if (!defined("gMOD")) {
            if (!empty($this->gbookSettings['gs_moderated'])) {
                if (checkgroup($moderated)) {
                    $gbmod = TRUE;
                }
            } else {
                $gbmod = TRUE;
            }
            define("gMOD", $gbmod);
        }
    }

    public function GbookNotify($level) {
        $result = dbquery("SELECT * FROM ".DB_USERS." WHERE user_level <= :ulevel", [':ulevel' => $level]);
        return $result;
    }

    public static function verifyGbook($id = NULL) {
        if (isnum($id)) {
            if (dbcount("(gb_id)", DB_GUESTBOOK, "gb_id = :gbid", [':gbid' => (int)$id])) {
                return TRUE;
            }
            return FALSE;
        }
        return FALSE;
    }

}
